Unexpected

Enum Unexpected 

pub enum Unexpected<'a> {
Show 18 variants Bool(bool), Unsigned(u64), Signed(i64), Float(f64), Char(char), Str(&'a str), Bytes(&'a [u8]), Unit, Option, NewtypeStruct, Seq, Map, Enum, UnitVariant, NewtypeVariant, TupleVariant, StructVariant, Other(&'a str),
}
Unexpected represents an unexpected invocation of any one of the Visitor trait methods.

This is used as an argument to the invalid_type, invalid_value, and invalid_length methods of the Error trait to build error messages.

fn visit_bool<E>(self, v: bool) -> Result<Self::Value, E>
where
    E: de::Error,
{
    Err(de::Error::invalid_type(Unexpected::Bool(v), &self))
}

Variants



Bool(bool)

The input contained a boolean value that was not expected.



Unsigned(u64)

The input contained an unsigned integer u8, u16, u32 or u64 that was not expected.



Signed(i64)

The input contained a signed integer i8, i16, i32 or i64 that was not expected.



Float(f64)

The input contained a floating point f32 or f64 that was not expected.



Char(char)

The input contained a char that was not expected.



Str(&'a str)

The input contained a &str or String that was not expected.



Bytes(&'a [u8])

The input contained a &[u8] or Vec<u8> that was not expected.



Unit

The input contained a unit () that was not expected.



Option

The input contained an Option<T> that was not expected.



NewtypeStruct

The input contained a newtype struct that was not expected.



Seq

The input contained a sequence that was not expected.



Map

The input contained a map that was not expected.



Enum

The input contained an enum that was not expected.



UnitVariant

The input contained a unit variant that was not expected.



NewtypeVariant

The input contained a newtype variant that was not expected.



TupleVariant

The input contained a tuple variant that was not expected.



StructVariant

The input contained a struct variant that was not expected.



Other(&'a str)

A message stating what uncategorized thing the input contained that was not expected.

The message should be a noun or noun phrase, not capitalized and without a period. An example message is “unoriginal superhero”.