pub struct IgnoredAny;Expand description
An efficient way of discarding data from a deserializer.
Think of this like serde_json::Value in that it can be deserialized from
any type, except that it does not store any information about the data that
gets deserialized.
use serde::de::{
self, Deserialize, DeserializeSeed, Deserializer, IgnoredAny, SeqAccess, Visitor,
};
use std::fmt;
use std::marker::PhantomData;
/// A seed that can be used to deserialize only the `n`th element of a sequence
/// while efficiently discarding elements of any type before or after index `n`.
///
/// For example to deserialize only the element at index 3:
///
/// ```
/// NthElement::new(3).deserialize(deserializer)
/// ```
pub struct NthElement<T> {
n: usize,
marker: PhantomData<T>,
}
impl<T> NthElement<T> {
pub fn new(n: usize) -> Self {
NthElement {
n: n,
marker: PhantomData,
}
}
}
impl<'de, T> Visitor<'de> for NthElement<T>
where
T: Deserialize<'de>,
{
type Value = T;
fn expecting(&self, formatter: &mut fmt::Formatter) -> fmt::Result {
write!(
formatter,
"a sequence in which we care about element {}",
self.n
)
}
fn visit_seq<A>(self, mut seq: A) -> Result<Self::Value, A::Error>
where
A: SeqAccess<'de>,
{
// Skip over the first `n` elements.
for i in 0..self.n {
// It is an error if the sequence ends before we get to element `n`.
if seq.next_element::<IgnoredAny>()?.is_none() {
return Err(de::Error::invalid_length(i, &self));
}
}
// Deserialize the one we care about.
let nth = match seq.next_element()? {
Some(nth) => nth,
None => {
return Err(de::Error::invalid_length(self.n, &self));
}
};
// Skip over any remaining elements in the sequence after `n`.
while let Some(IgnoredAny) = seq.next_element()? {
// ignore
}
Ok(nth)
}
}
impl<'de, T> DeserializeSeed<'de> for NthElement<T>
where
T: Deserialize<'de>,
{
type Value = T;
fn deserialize<D>(self, deserializer: D) -> Result<Self::Value, D::Error>
where
D: Deserializer<'de>,
{
deserializer.deserialize_seq(self)
}
}
// Deserialize only the sequence element at index 3 from this deserializer.
// The element at index 3 is required to be a string. Elements before and
// after index 3 are allowed to be of any type.
let s: String = NthElement::new(3).deserialize(deserializer)?;Trait Implementations
Sourceimpl Clone for IgnoredAny
impl Clone for IgnoredAny
Sourcefn clone(&self) -> IgnoredAny
fn clone(&self) -> IgnoredAny
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for IgnoredAny
impl Debug for IgnoredAny
Sourceimpl Default for IgnoredAny
impl Default for IgnoredAny
Sourcefn default() -> IgnoredAny
fn default() -> IgnoredAny
Sourceimpl<'de> Deserialize<'de> for IgnoredAny
impl<'de> Deserialize<'de> for IgnoredAny
Sourcefn deserialize<D>(
deserializer: D,
) -> Result<IgnoredAny, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn deserialize<D>(
deserializer: D,
) -> Result<IgnoredAny, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Sourceimpl PartialEq for IgnoredAny
impl PartialEq for IgnoredAny
Sourceimpl<'de> Visitor<'de> for IgnoredAny
impl<'de> Visitor<'de> for IgnoredAny
Sourcetype Value = IgnoredAny
type Value = IgnoredAny
Sourcefn expecting(&self, formatter: &mut Formatter<'_>) -> Result<(), Error>
fn expecting(&self, formatter: &mut Formatter<'_>) -> Result<(), Error>
Sourcefn visit_bool<E>(
self,
x: bool,
) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>
fn visit_bool<E>( self, x: bool, ) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>
Sourcefn visit_i64<E>(self, x: i64) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>
fn visit_i64<E>(self, x: i64) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>
i64. Read moreSourcefn visit_i128<E>(
self,
x: i128,
) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>
fn visit_i128<E>( self, x: i128, ) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>
i128. Read moreSourcefn visit_u64<E>(self, x: u64) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>
fn visit_u64<E>(self, x: u64) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>
u64. Read moreSourcefn visit_u128<E>(
self,
x: u128,
) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>
fn visit_u128<E>( self, x: u128, ) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>
u128. Read moreSourcefn visit_f64<E>(self, x: f64) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>
fn visit_f64<E>(self, x: f64) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>
f64. Read moreSourcefn visit_str<E>(self, s: &str) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>where
E: Error,
fn visit_str<E>(self, s: &str) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>where
E: Error,
Sourcefn visit_none<E>(self) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>
fn visit_none<E>(self) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>
Sourcefn visit_some<D>(
self,
deserializer: D,
) -> Result<<IgnoredAny as Visitor<'de>>::Value, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn visit_some<D>(
self,
deserializer: D,
) -> Result<<IgnoredAny as Visitor<'de>>::Value, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Sourcefn visit_newtype_struct<D>(
self,
deserializer: D,
) -> Result<<IgnoredAny as Visitor<'de>>::Value, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
fn visit_newtype_struct<D>(
self,
deserializer: D,
) -> Result<<IgnoredAny as Visitor<'de>>::Value, <D as Deserializer<'de>>::Error>where
D: Deserializer<'de>,
Sourcefn visit_unit<E>(self) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>
fn visit_unit<E>(self) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>
(). Read moreSourcefn visit_seq<A>(
self,
seq: A,
) -> Result<<IgnoredAny as Visitor<'de>>::Value, <A as SeqAccess<'de>>::Error>where
A: SeqAccess<'de>,
fn visit_seq<A>(
self,
seq: A,
) -> Result<<IgnoredAny as Visitor<'de>>::Value, <A as SeqAccess<'de>>::Error>where
A: SeqAccess<'de>,
Sourcefn visit_map<A>(
self,
map: A,
) -> Result<<IgnoredAny as Visitor<'de>>::Value, <A as MapAccess<'de>>::Error>where
A: MapAccess<'de>,
fn visit_map<A>(
self,
map: A,
) -> Result<<IgnoredAny as Visitor<'de>>::Value, <A as MapAccess<'de>>::Error>where
A: MapAccess<'de>,
Sourcefn visit_bytes<E>(
self,
bytes: &[u8],
) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>where
E: Error,
fn visit_bytes<E>(
self,
bytes: &[u8],
) -> Result<<IgnoredAny as Visitor<'de>>::Value, E>where
E: Error,
Sourcefn visit_enum<A>(
self,
data: A,
) -> Result<<IgnoredAny as Visitor<'de>>::Value, <A as EnumAccess<'de>>::Error>where
A: EnumAccess<'de>,
fn visit_enum<A>(
self,
data: A,
) -> Result<<IgnoredAny as Visitor<'de>>::Value, <A as EnumAccess<'de>>::Error>where
A: EnumAccess<'de>,
Sourcefn visit_i8<E>(self, v: i8) -> Result<Self::Value, E>where
E: Error,
fn visit_i8<E>(self, v: i8) -> Result<Self::Value, E>where
E: Error,
i8. Read moreSourcefn visit_i16<E>(self, v: i16) -> Result<Self::Value, E>where
E: Error,
fn visit_i16<E>(self, v: i16) -> Result<Self::Value, E>where
E: Error,
i16. Read moreSourcefn visit_i32<E>(self, v: i32) -> Result<Self::Value, E>where
E: Error,
fn visit_i32<E>(self, v: i32) -> Result<Self::Value, E>where
E: Error,
i32. Read moreSourcefn visit_u8<E>(self, v: u8) -> Result<Self::Value, E>where
E: Error,
fn visit_u8<E>(self, v: u8) -> Result<Self::Value, E>where
E: Error,
u8. Read moreSourcefn visit_u16<E>(self, v: u16) -> Result<Self::Value, E>where
E: Error,
fn visit_u16<E>(self, v: u16) -> Result<Self::Value, E>where
E: Error,
u16. Read moreSourcefn visit_u32<E>(self, v: u32) -> Result<Self::Value, E>where
E: Error,
fn visit_u32<E>(self, v: u32) -> Result<Self::Value, E>where
E: Error,
u32. Read moreSourcefn visit_f32<E>(self, v: f32) -> Result<Self::Value, E>where
E: Error,
fn visit_f32<E>(self, v: f32) -> Result<Self::Value, E>where
E: Error,
f32. Read moreSourcefn visit_char<E>(self, v: char) -> Result<Self::Value, E>where
E: Error,
fn visit_char<E>(self, v: char) -> Result<Self::Value, E>where
E: Error,
char. Read moreSourcefn visit_borrowed_str<E>(self, v: &'de str) -> Result<Self::Value, E>where
E: Error,
fn visit_borrowed_str<E>(self, v: &'de str) -> Result<Self::Value, E>where
E: Error,
Deserializer. Read moreSourcefn visit_string<E>(self, v: String) -> Result<Self::Value, E>where
E: Error,
fn visit_string<E>(self, v: String) -> Result<Self::Value, E>where
E: Error,
Visitor. Read moreimpl Copy for IgnoredAny
impl StructuralPartialEq for IgnoredAny