pub enum ChatCompletionRequestUserMessageContent {
Text(String),
Array(Vec<ChatCompletionRequestUserMessageContentPart>),
}Variants
Text(String)
The text contents of the message.
Array(Vec<ChatCompletionRequestUserMessageContentPart>)
An array of content parts with a defined type. Supported options differ based on the model being used to generate the response. Can contain text, image, or audio inputs.