pub enum OpenAIError {
Reqwest(Error),
ApiError(ApiError),
JSONDeserialize(Error),
FileSaveError(String),
FileReadError(String),
StreamError(String),
InvalidArgument(String),
}Variants
Reqwest(Error)
Underlying error from reqwest library after an API call was made
ApiError(ApiError)
OpenAI returns error object with details of API call failure
JSONDeserialize(Error)
Error when a response cannot be deserialized into a Rust type
FileSaveError(String)
Error on the client side when saving file to file system
FileReadError(String)
Error on the client side when reading file from file system
StreamError(String)
Error on SSE streaming
InvalidArgument(String)
Error from client side validation or when builder fails to build request before making API call