pub struct OnceRef<'a, T> { /* private fields */ }Expand description
A thread-safe cell which can be written to only once.
Implementations
Sourceimpl<'a, T> OnceRef<'a, T>
impl<'a, T> OnceRef<'a, T>
Sourcepub fn set(&self, value: &'a T) -> Result<(), ()>
pub fn set(&self, value: &'a T) -> Result<(), ()>
Sets the contents of this cell to value.
Returns Ok(()) if the cell was empty and Err(value) if it was
full.
Sourcepub fn get_or_init<F>(&self, f: F) -> &'a T
pub fn get_or_init<F>(&self, f: F) -> &'a T
Gets the contents of the cell, initializing it with f if the cell was
empty.
If several threads concurrently run get_or_init, more than one f can
be called. However, all threads will return the same value, produced by
some f.
Sourcepub fn get_or_try_init<F, E>(&self, f: F) -> Result<&'a T, E>
pub fn get_or_try_init<F, E>(&self, f: F) -> Result<&'a T, E>
Gets the contents of the cell, initializing it with f if
the cell was empty. If the cell was empty and f failed, an
error is returned.
If several threads concurrently run get_or_init, more than one f can
be called. However, all threads will return the same value, produced by
some f.