Batch

Struct Batch 

pub struct Batch {
Show 20 fields pub id: String, pub object: String, pub endpoint: String, pub errors: Option<BatchErrors>, pub input_file_id: String, pub completion_window: String, pub status: BatchStatus, pub output_file_id: Option<String>, pub error_file_id: Option<String>, pub created_at: u32, pub in_progress_at: Option<u32>, pub expires_at: Option<u32>, pub finalizing_at: Option<u32>, pub completed_at: Option<u32>, pub failed_at: Option<u32>, pub expired_at: Option<u32>, pub cancelling_at: Option<u32>, pub cancelled_at: Option<u32>, pub request_counts: Option<BatchRequestCounts>, pub metadata: Option<HashMap<String, Value>>,
}

Fields

id: Stringobject: String

The object type, which is always batch.

endpoint: String

The OpenAI API endpoint used by the batch.

errors: Option<BatchErrors>input_file_id: String

The ID of the input file for the batch.

completion_window: String

The time frame within which the batch should be processed.

status: BatchStatus

The current status of the batch.

output_file_id: Option<String>

The ID of the file containing the outputs of successfully executed requests.

error_file_id: Option<String>

The ID of the file containing the outputs of requests with errors.

created_at: u32

The Unix timestamp (in seconds) for when the batch was created.

in_progress_at: Option<u32>

The Unix timestamp (in seconds) for when the batch started processing.

expires_at: Option<u32>

The Unix timestamp (in seconds) for when the batch will expire.

finalizing_at: Option<u32>

The Unix timestamp (in seconds) for when the batch started finalizing.

completed_at: Option<u32>

The Unix timestamp (in seconds) for when the batch was completed.

failed_at: Option<u32>

The Unix timestamp (in seconds) for when the batch failed.

expired_at: Option<u32>

he Unix timestamp (in seconds) for when the batch expired.

cancelling_at: Option<u32>

The Unix timestamp (in seconds) for when the batch started cancelling.

cancelled_at: Option<u32>

The Unix timestamp (in seconds) for when the batch was cancelled.

request_counts: Option<BatchRequestCounts>

The request counts for different statuses within the batch.

metadata: Option<HashMap<String, Value>>

Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format. Keys can be a maximum of 64 characters long and values can be a maximum of 512 characters long.