pub struct BatchRequest {
pub input_file_id: String,
pub endpoint: BatchEndpoint,
pub completion_window: BatchCompletionWindow,
pub metadata: Option<HashMap<String, Value>>,
}Fields
input_file_id: StringThe ID of an uploaded file that contains requests for the new batch.
See upload file for how to upload a file.
Your input file must be formatted as a JSONL file, and must be uploaded with the purpose batch. The file can contain up to 50,000 requests, and can be up to 100 MB in size.
endpoint: BatchEndpointThe endpoint to be used for all requests in the batch. Currently /v1/chat/completions, /v1/embeddings, and /v1/completions are supported. Note that /v1/embeddings batches are also restricted to a maximum of 50,000 embedding inputs across all requests in the batch.
completion_window: BatchCompletionWindowThe time frame within which the batch should be processed. Currently only 24h is supported.
metadata: Option<HashMap<String, Value>>Optional custom metadata for the batch.