pub struct BatchRequestOutput {
pub id: String,
pub custom_id: String,
pub response: Option<BatchRequestOutputResponse>,
pub error: Option<BatchRequestOutputError>,
}Expand description
The per-line object of the batch output and error files
Fields
id: Stringcustom_id: StringA developer-provided per-request id that will be used to match outputs to inputs.
response: Option<BatchRequestOutputResponse>error: Option<BatchRequestOutputError>For requests that failed with a non-HTTP error, this will contain more information on the cause of the failure.