pub struct ChatCompletionResponseMessage {
pub content: Option<String>,
pub refusal: Option<String>,
pub tool_calls: Option<Vec<ChatCompletionMessageToolCall>>,
pub role: Role,
pub function_call: Option<FunctionCall>,
pub audio: Option<ChatCompletionResponseMessageAudio>,
}Expand description
A chat completion message generated by the model.
Fields
content: Option<String>The contents of the message.
refusal: Option<String>The refusal message generated by the model.
tool_calls: Option<Vec<ChatCompletionMessageToolCall>>The tool calls generated by the model, such as function calls.
role: RoleThe role of the author of this message.
function_call: Option<FunctionCall>Deprecated and replaced by tool_calls.
The name and arguments of a function that should be called, as generated by the model.
audio: Option<ChatCompletionResponseMessageAudio>If the audio output modality is requested, this object contains data about the audio response from the model. Learn more.