pub struct OpenAIFile {
pub id: String,
pub object: String,
pub bytes: u32,
pub created_at: u32,
pub filename: String,
pub purpose: OpenAIFilePurpose,
pub status: Option<String>,
pub status_details: Option<String>,
}Expand description
The File object represents a document that has been uploaded to OpenAI.
Fields
id: StringThe file identifier, which can be referenced in the API endpoints.
object: StringThe object type, which is always “file”.
bytes: u32The size of the file in bytes.
created_at: u32The Unix timestamp (in seconds) for when the file was created.
filename: StringThe name of the file.
purpose: OpenAIFilePurposeThe intended purpose of the file. Supported values are assistants, assistants_output, batch, batch_output, fine-tune, fine-tune-results and vision.
status: Option<String>Deprecated. The current status of the file, which can be either uploaded, processed, or error.
status_details: Option<String>Deprecated. For details on why a fine-tuning training file failed validation, see the error field on fine_tuning.job.