Display

Trait Display 

1.0.0 · Source
pub trait Display {
    // Required method
    fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>;
}
Format trait for an empty format, {}.

Implementing this trait for a type will automatically implement the ToString trait for the type, allowing the usage of the .to_string() method. Prefer implementing the Display trait for a type, rather than ToString.

Display is similar to Debug, but Display is for user-facing output, and so cannot be derived.

For more information on formatters, see the module-level documentation.

Completeness and parseability

Display for a type might not necessarily be a lossless or complete representation of the type. It may omit internal state, precision, or other information the type does not consider important for user-facing output, as determined by the type. As such, the output of Display might not be possible to parse, and even if it is, the result of parsing might not exactly match the original value.

However, if a type has a lossless Display implementation whose output is meant to be conveniently machine-parseable and not just meant for human consumption, then the type may wish to accept the same format in FromStr, and document that usage. Having both Display and FromStr implementations where the result of Display cannot be parsed with FromStr may surprise users.

Internationalization

Because a type can only have one Display implementation, it is often preferable to only implement Display when there is a single most “obvious” way that values can be formatted as text. This could mean formatting according to the “invariant” culture and “undefined” locale, or it could mean that the type display is designed for a specific culture/locale, such as developer logs.

If not all values have a justifiably canonical textual format or if you want to support alternative formats not covered by the standard set of possible formatting traits, the most flexible approach is display adapters: methods like str::escape_default or Path::display which create a wrapper implementing Display to output the specific display format.

Examples

Implementing Display on a type:

use std::fmt;

struct Point {
    x: i32,
    y: i32,
}

impl fmt::Display for Point {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.x, self.y)
    }
}

let origin = Point { x: 0, y: 0 };

assert_eq!(format!("The origin is: {origin}"), "The origin is: (0, 0)");

Required Methods

1.0.0 · Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result<(), Error>

Formats the value using the given formatter.

Errors

This function should return Err if, and only if, the provided Formatter returns Err. String formatting is considered an infallible operation; this function only returns a Result because writing to the underlying stream might fail and it must provide a way to propagate the fact that an error has occurred back up the stack.

Examples
use std::fmt;

struct Position {
    longitude: f32,
    latitude: f32,
}

impl fmt::Display for Position {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        write!(f, "({}, {})", self.longitude, self.latitude)
    }
}

assert_eq!(
    "(1.987, 2.983)",
    format!("{}", Position { longitude: 1.987, latitude: 2.983, }),
);

Implementors

1.60.0 · Source

impl Display for batch_mode_3p::ErrorKind

Source

impl Display for FilePurpose

Source

impl Display for JsonRepairError

Source

impl Display for batch_mode_3p::JsonValue

Source

impl Display for OpenAIError

Source

impl Display for Role

Source

impl Display for AsciiChar

1.34.0 · Source

impl Display for Infallible

1.17.0 · Source

impl Display for FromBytesWithNulError

1.7.0 · Source

impl Display for IpAddr

1.0.0 · Source

impl Display for SocketAddr

1.86.0 · Source

impl Display for core::slice::GetDisjointMutError

1.0.0 · Source

impl Display for VarError

1.89.0 · Source

impl Display for std::fs::TryLockError

1.15.0 · Source

impl Display for std::sync::mpsc::RecvTimeoutError

1.0.0 · Source

impl Display for std::sync::mpsc::TryRecvError

Source

impl Display for AudioResponseFormat

Source

impl Display for TimestampGranularity

Source

impl Display for ChatCompletionRequestMessageContentPartRefusalBuilderError

Source

impl Display for DallE2ImageSize

Source

impl Display for ImageModel

Source

impl Display for ImageResponseFormat

Source

impl Display for ImageSize

Source

impl Display for ComputerUsePreviewArgsError

Source

impl Display for FunctionArgsError

Source

impl Display for WebSearchPreviewArgsError

Source

impl Display for ParseAlphabetError

Source

impl Display for DecodeError

Source

impl Display for DecodeSliceError

Source

impl Display for EncodeSliceError

Source

impl Display for RoundingError

Source

impl Display for chrono::weekday::Weekday

Source

impl Display for Shell

Source

impl Display for crossbeam_channel::err::RecvTimeoutError

Source

impl Display for crossbeam_channel::err::TryRecvError

Source

impl Display for httparse::Error

Source

impl Display for GetTimezoneError

Source

impl Display for InvalidStringList

Source

impl Display for icu_collections::codepointtrie::error::Error

Source

impl Display for icu_locale_core::parser::errors::ParseError

Source

impl Display for PreferencesParseError

Source

impl Display for DataErrorKind

Source

impl Display for IpNet

Source

impl Display for json5::error::Error

Source

impl Display for log::Level

Source

impl Display for log::LevelFilter

Source

impl Display for rand::distr::bernoulli::BernoulliError

Source

impl Display for rand::distr::uniform::Error

Source

impl Display for rand::distr::weighted::Error

Source

impl Display for rand::distributions::bernoulli::BernoulliError

Source

impl Display for WeightedError

Source

impl Display for StartError

Source

impl Display for regex_syntax::ast::Ast

Print a display representation of this Ast.

This does not preserve any of the original whitespace formatting that may have originally been present in the concrete syntax from which this Ast was generated.

This implementation uses constant stack space and heap space proportional to the size of the Ast.

Source

impl Display for regex_syntax::ast::Ast

Print a display representation of this Ast.

This does not preserve any of the original whitespace formatting that may have originally been present in the concrete syntax from which this Ast was generated.

This implementation uses constant stack space and heap space proportional to the size of the Ast.

Source

impl Display for regex_syntax::ast::ErrorKind

Source

impl Display for regex_syntax::ast::ErrorKind

Source

impl Display for regex_syntax::error::Error

Source

impl Display for regex_syntax::error::Error

Source

impl Display for regex_syntax::hir::ErrorKind

Source

impl Display for regex_syntax::hir::ErrorKind

Source

impl Display for regex::error::Error

Source

impl Display for reqwest_eventsource::error::Error

Source

impl Display for rustls_pki_types::pem::Error

Source

impl Display for webpki::error::Error

Source

impl Display for EarlyDataError

Source

impl Display for EncodeError

Source

impl Display for EncryptError

Source

impl Display for CertificateError

Source

impl Display for rustls::error::Error

Source

impl Display for ExtendedKeyPurpose

Source

impl Display for VerifierBuilderError

Source

impl Display for serde_urlencoded::ser::Error

Source

impl Display for slab::GetDisjointMutError

Source

impl Display for CollectionAllocErr

Source

impl Display for StrSimError

Source

impl Display for strum::ParseError

Source

impl Display for time::error::Error

Source

impl Display for Format

Source

impl Display for InvalidFormatDescription

Source

impl Display for Parse

Source

impl Display for ParseFromDescription

Source

impl Display for TryFromParsed

Source

impl Display for Month

Source

impl Display for time::weekday::Weekday

Source

impl Display for tinystr::error::ParseError

Source

impl Display for AnyDelimiterCodecError

Source

impl Display for LinesCodecError

Source

impl Display for TryAcquireError

Source

impl Display for tokio::sync::broadcast::error::RecvError

Source

impl Display for tokio::sync::broadcast::error::TryRecvError

Source

impl Display for ServerErrorsFailureClass

Source

impl Display for GrpcFailureClass

Source

impl Display for StatusInRangeFailureClass

Source

impl Display for ucd_trie::owned::Error

Source

impl Display for url::parser::ParseError

Source

impl Display for SyntaxViolation

Source

impl Display for uuid::Variant

Source

impl Display for BigEndian

Source

impl Display for LittleEndian

Source

impl Display for ZeroTrieBuildError

Source

impl Display for UleError

Source

impl Display for batch_mode_3p::mpsc::error::TryRecvError

Source

impl Display for batch_mode_3p::oneshot::error::TryRecvError

1.0.0 · Source

impl Display for bool

1.0.0 · Source

impl Display for char

1.0.0 · Source

impl Display for f16

1.0.0 · Source

impl Display for f32

1.0.0 · Source

impl Display for f64

1.0.0 · Source

impl Display for i8

1.0.0 · Source

impl Display for i16

1.0.0 · Source

impl Display for i32

1.0.0 · Source

impl Display for i64

1.0.0 · Source

impl Display for i128

1.0.0 · Source

impl Display for isize

Source

impl Display for !

1.0.0 · Source

impl Display for str

1.0.0 · Source

impl Display for u8

1.0.0 · Source

impl Display for u16

1.0.0 · Source

impl Display for u32

1.0.0 · Source

impl Display for u64

1.0.0 · Source

impl Display for u128

1.0.0 · Source

impl Display for usize

Source

impl Display for ColoredString

Source

impl Display for batch_mode_3p::de::value::Error

Source

impl Display for ByteString

Source

impl Display for UnorderedKeyError

1.57.0 · Source

impl Display for TryReserveError

1.58.0 · Source

impl Display for FromVecWithNulError

1.7.0 · Source

impl Display for IntoStringError

1.0.0 · Source

impl Display for NulError

1.0.0 · Source

impl Display for FromUtf8Error

1.0.0 · Source

impl Display for FromUtf16Error

1.0.0 · Source

impl Display for String

1.28.0 · Source

impl Display for LayoutError

Source

impl Display for AllocError

1.35.0 · Source

impl Display for TryFromSliceError

1.39.0 · Source

impl Display for core::ascii::EscapeDefault

Source

impl Display for ByteStr

1.13.0 · Source

impl Display for BorrowError

1.13.0 · Source

impl Display for BorrowMutError

1.34.0 · Source

impl Display for CharTryFromError

1.20.0 · Source

impl Display for ParseCharError

1.9.0 · Source

impl Display for DecodeUtf16Error

1.20.0 · Source

impl Display for core::char::EscapeDebug

1.16.0 · Source

impl Display for core::char::EscapeDefault

1.16.0 · Source

impl Display for core::char::EscapeUnicode

1.16.0 · Source

impl Display for ToLowercase

1.16.0 · Source

impl Display for ToUppercase

1.59.0 · Source

impl Display for TryFromCharError

1.69.0 · Source

impl Display for FromBytesUntilNulError

1.0.0 · Source

impl Display for Arguments<'_>

1.0.0 · Source

impl Display for core::fmt::Error

1.0.0 · Source

impl Display for Ipv4Addr

1.0.0 · Source

impl Display for Ipv6Addr

Writes an Ipv6Addr, conforming to the canonical style described by RFC 5952.

1.4.0 · Source

impl Display for core::net::parser::AddrParseError

1.0.0 · Source

impl Display for SocketAddrV4

1.0.0 · Source

impl Display for SocketAddrV6

1.0.0 · Source

impl Display for core::num::dec2flt::ParseFloatError

1.0.0 · Source

impl Display for core::num::error::ParseIntError

1.34.0 · Source

impl Display for core::num::error::TryFromIntError

1.26.0 · Source

impl Display for Location<'_>

1.26.0 · Source

impl Display for PanicInfo<'_>

1.81.0 · Source

impl Display for PanicMessage<'_>

1.0.0 · Source

impl Display for ParseBoolError

1.0.0 · Source

impl Display for Utf8Error

1.66.0 · Source

impl Display for TryFromFloatSecsError

1.65.0 · Source

impl Display for Backtrace

1.0.0 · Source

impl Display for JoinPathsError

1.87.0 · Source

impl Display for std::ffi::os_str::Display<'_>

1.56.0 · Source

impl Display for WriterPanicked

1.26.0 · Source

impl Display for PanicHookInfo<'_>

1.0.0 · Source

impl Display for std::path::Display<'_>

Source

impl Display for NormalizeError

1.7.0 · Source

impl Display for StripPrefixError

1.0.0 · Source

impl Display for ExitStatus

Source

impl Display for ExitStatusError

1.0.0 · Source

impl Display for std::sync::mpsc::RecvError

Source

impl Display for WouldBlock

1.8.0 · Source

impl Display for SystemTimeError

Source

impl Display for aho_corasick::util::error::BuildError

Source

impl Display for aho_corasick::util::error::MatchError

Source

impl Display for aho_corasick::util::primitives::PatternIDError

Source

impl Display for aho_corasick::util::primitives::StateIDError

Source

impl Display for Infix

Source

impl Display for Prefix

Source

impl Display for Suffix

Source

impl Display for StrippedStr<'_>

Source

impl Display for Reset

Source

impl Display for Style

Source

impl Display for bitflags::parser::ParseError

Source

impl Display for TryGetError

Source

impl Display for chrono::format::ParseError

Source

impl Display for ParseMonthError

Source

impl Display for NaiveDate

The Display output of the naive date d is the same as d.format("%Y-%m-%d").

The string printed can be readily parsed via the parse method on str.

Example

use chrono::NaiveDate;

assert_eq!(format!("{}", NaiveDate::from_ymd_opt(2015, 9, 5).unwrap()), "2015-09-05");
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(0, 1, 1).unwrap()), "0000-01-01");
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(9999, 12, 31).unwrap()), "9999-12-31");

ISO 8601 requires an explicit sign for years before 1 BCE or after 9999 CE.

assert_eq!(format!("{}", NaiveDate::from_ymd_opt(-1, 1, 1).unwrap()), "-0001-01-01");
assert_eq!(format!("{}", NaiveDate::from_ymd_opt(10000, 12, 31).unwrap()), "+10000-12-31");
Source

impl Display for NaiveDateTime

The Display output of the naive date and time dt is the same as dt.format("%Y-%m-%d %H:%M:%S%.f").

It should be noted that, for leap seconds not on the minute boundary, it may print a representation not distinguishable from non-leap seconds. This doesn’t matter in practice, since such leap seconds never happened. (By the time of the first leap second on 1972-06-30, every time zone offset around the world has standardized to the 5-minute alignment.)

Example

use chrono::NaiveDate;

let dt = NaiveDate::from_ymd_opt(2016, 11, 15).unwrap().and_hms_opt(7, 39, 24).unwrap();
assert_eq!(format!("{}", dt), "2016-11-15 07:39:24");

Leap seconds may also be used.

let dt =
    NaiveDate::from_ymd_opt(2015, 6, 30).unwrap().and_hms_milli_opt(23, 59, 59, 1_500).unwrap();
assert_eq!(format!("{}", dt), "2015-06-30 23:59:60.500");
Source

impl Display for NaiveTime

The Display output of the naive time t is the same as t.format("%H:%M:%S%.f").

The string printed can be readily parsed via the parse method on str.

It should be noted that, for leap seconds not on the minute boundary, it may print a representation not distinguishable from non-leap seconds. This doesn’t matter in practice, since such leap seconds never happened. (By the time of the first leap second on 1972-06-30, every time zone offset around the world has standardized to the 5-minute alignment.)

Example

use chrono::NaiveTime;

assert_eq!(format!("{}", NaiveTime::from_hms_opt(23, 56, 4).unwrap()), "23:56:04");
assert_eq!(
    format!("{}", NaiveTime::from_hms_milli_opt(23, 56, 4, 12).unwrap()),
    "23:56:04.012"
);
assert_eq!(
    format!("{}", NaiveTime::from_hms_micro_opt(23, 56, 4, 1234).unwrap()),
    "23:56:04.001234"
);
assert_eq!(
    format!("{}", NaiveTime::from_hms_nano_opt(23, 56, 4, 123456).unwrap()),
    "23:56:04.000123456"
);

Leap seconds may also be used.

assert_eq!(
    format!("{}", NaiveTime::from_hms_milli_opt(6, 59, 59, 1_500).unwrap()),
    "06:59:60.500"
);
Source

impl Display for FixedOffset

Source

impl Display for Utc

Source

impl Display for OutOfRange

Source

impl Display for OutOfRangeError

Source

impl Display for TimeDelta

Source

impl Display for ParseWeekdayError

Source

impl Display for WeekdaySet

Print the collection as a slice-like list of weekdays.

Example

use chrono::Weekday::*;
assert_eq!("[]", WeekdaySet::EMPTY.to_string());
assert_eq!("[Mon]", WeekdaySet::single(Mon).to_string());
assert_eq!("[Mon, Fri, Sun]", WeekdaySet::from_array([Mon, Fri, Sun]).to_string());
Source

impl Display for clap::errors::Error

Source

impl Display for crossbeam_channel::err::RecvError

Source

impl Display for SelectTimeoutError

Source

impl Display for TrySelectError

Source

impl Display for deranged::ParseIntError

Source

impl Display for deranged::TryFromIntError

Source

impl Display for UninitializedFieldError

Source

impl Display for env_filter::parser::ParseError

Source

impl Display for env_logger::fmt::humantime::Timestamp

Source

impl Display for futures_channel::mpsc::SendError

Source

impl Display for futures_channel::mpsc::TryRecvError

Source

impl Display for Canceled

Source

impl Display for EnterError

Source

impl Display for SpawnError

Source

impl Display for Aborted

Source

impl Display for getrandom::error::Error

Source

impl Display for getrandom::error::Error

Source

impl Display for LengthLimitError

Source

impl Display for http::error::Error

Source

impl Display for MaxSizeReached

Source

impl Display for HeaderName

Source

impl Display for InvalidHeaderName

Source

impl Display for InvalidHeaderValue

Source

impl Display for ToStrError

Source

impl Display for InvalidMethod

Source

impl Display for Method

Source

impl Display for InvalidStatusCode

Source

impl Display for StatusCode

Formats the status code, including the canonical reason.

Example

assert_eq!(format!("{}", StatusCode::OK), "200 OK");
Source

impl Display for Authority

Source

impl Display for PathAndQuery

Source

impl Display for Scheme

Source

impl Display for InvalidUri

Source

impl Display for InvalidUriParts

Source

impl Display for Uri

Source

impl Display for InvalidChunkSize

Source

impl Display for hyper_util::client::legacy::client::Error

Source

impl Display for InvalidNameError

Source

impl Display for hyper_util::client::legacy::connect::dns::Name

Source

impl Display for hyper::error::Error

Source

impl Display for InvalidSetError

Source

impl Display for RangeError

Source

impl Display for DataLocale

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Other

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::extensions::private::other::Subtag

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Private

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Fields

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::extensions::transform::key::Key

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Transform

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::extensions::transform::value::Value

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Attribute

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Attributes

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::extensions::unicode::key::Key

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Keywords

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Unicode

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for SubdivisionId

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for SubdivisionSuffix

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::extensions::unicode::value::Value

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for LanguageIdentifier

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Locale

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Language

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Region

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Script

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::subtags::Subtag

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for icu_locale_core::subtags::variant::Variant

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for Variants

This trait is implemented for compatibility with fmt!. To create a string, [Writeable::write_to_string] is usually more efficient.

Source

impl Display for DataError

Source

impl Display for DataIdentifierBorrowed<'_>

Source

impl Display for Errors

Source

impl Display for Ipv4Net

Source

impl Display for Ipv6Net

Source

impl Display for PrefixLenError

Source

impl Display for ipnet::parser::AddrParseError

Source

impl Display for CapacityOverflowError

Source

impl Display for iri_string::normalize::error::Error

Source

impl Display for iri_string::template::error::Error

Source

impl Display for UriTemplateString

Source

impl Display for UriTemplateStr

Source

impl Display for iri_string::validate::Error

Source

impl Display for jiff::civil::date::Date

Source

impl Display for jiff::civil::datetime::DateTime

Converts a DateTime into an ISO 8601 compliant string.

Formatting options supported

  • std::fmt::Formatter::precision can be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.

Example

This shows the default rendering:

use jiff::civil::date;

// No fractional seconds:
let dt = date(2024, 6, 15).at(7, 0, 0, 0);
assert_eq!(format!("{dt}"), "2024-06-15T07:00:00");

// With fractional seconds:
let dt = date(2024, 6, 15).at(7, 0, 0, 123_000_000);
assert_eq!(format!("{dt}"), "2024-06-15T07:00:00.123");

Example: setting the precision

use jiff::civil::date;

let dt = date(2024, 6, 15).at(7, 0, 0, 123_000_000);
assert_eq!(format!("{dt:.6}"), "2024-06-15T07:00:00.123000");
// Precision values greater than 9 are clamped to 9.
assert_eq!(format!("{dt:.300}"), "2024-06-15T07:00:00.123000000");
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(format!("{dt:.0}"), "2024-06-15T07:00:00");
Source

impl Display for jiff::civil::time::Time

Converts a Time into an ISO 8601 compliant string.

Formatting options supported

  • std::fmt::Formatter::precision can be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.

Example

use jiff::civil::time;

// No fractional seconds:
let t = time(7, 0, 0, 0);
assert_eq!(format!("{t}"), "07:00:00");

// With fractional seconds:
let t = time(7, 0, 0, 123_000_000);
assert_eq!(format!("{t}"), "07:00:00.123");

Example: setting the precision

use jiff::civil::time;

let t = time(7, 0, 0, 123_000_000);
assert_eq!(format!("{t:.6}"), "07:00:00.123000");
// Precision values greater than 9 are clamped to 9.
assert_eq!(format!("{t:.300}"), "07:00:00.123000000");
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(format!("{t:.0}"), "07:00:00");
Source

impl Display for jiff::error::Error

Source

impl Display for SignedDuration

Source

impl Display for Span

Source

impl Display for jiff::timestamp::Timestamp

Converts a Timestamp datetime into a RFC 3339 compliant string.

Since a Timestamp never has an offset associated with it and is always in UTC, the string emitted by this trait implementation uses Z for “Zulu” time. The significance of Zulu time is prescribed by RFC 9557 and means that “the time in UTC is known, but the offset to local time is unknown.” If you need to emit an RFC 3339 compliant string with a specific offset, then use Timestamp::display_with_offset.

Formatting options supported

  • std::fmt::Formatter::precision can be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.

Example

This shows the default rendering:

use jiff::Timestamp;

// No fractional seconds.
let ts = Timestamp::from_second(1_123_456_789)?;
assert_eq!(format!("{ts}"), "2005-08-07T23:19:49Z");

// With fractional seconds.
let ts = Timestamp::new(1_123_456_789, 123_000_000)?;
assert_eq!(format!("{ts}"), "2005-08-07T23:19:49.123Z");

Example: setting the precision

use jiff::Timestamp;

let ts = Timestamp::new(1_123_456_789, 123_000_000)?;
assert_eq!(
    format!("{ts:.6}"),
    "2005-08-07T23:19:49.123000Z",
);
// Precision values greater than 9 are clamped to 9.
assert_eq!(
    format!("{ts:.300}"),
    "2005-08-07T23:19:49.123000000Z",
);
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(
    format!("{ts:.0}"),
    "2005-08-07T23:19:49Z",
);
Source

impl Display for TimestampDisplayWithOffset

Source

impl Display for Offset

Source

impl Display for Zoned

Converts a Zoned datetime into a RFC 9557 compliant string.

Formatting options supported

  • std::fmt::Formatter::precision can be set to control the precision of the fractional second component. When not set, the minimum precision required to losslessly render the value is used.

Example

This shows the default rendering:

use jiff::civil::date;

// No fractional seconds:
let zdt = date(2024, 6, 15).at(7, 0, 0, 0).in_tz("US/Eastern")?;
assert_eq!(format!("{zdt}"), "2024-06-15T07:00:00-04:00[US/Eastern]");

// With fractional seconds:
let zdt = date(2024, 6, 15).at(7, 0, 0, 123_000_000).in_tz("US/Eastern")?;
assert_eq!(format!("{zdt}"), "2024-06-15T07:00:00.123-04:00[US/Eastern]");

Example: setting the precision

use jiff::civil::date;

let zdt = date(2024, 6, 15).at(7, 0, 0, 123_000_000).in_tz("US/Eastern")?;
assert_eq!(
    format!("{zdt:.6}"),
    "2024-06-15T07:00:00.123000-04:00[US/Eastern]",
);
// Precision values greater than 9 are clamped to 9.
assert_eq!(
    format!("{zdt:.300}"),
    "2024-06-15T07:00:00.123000000-04:00[US/Eastern]",
);
// A precision of 0 implies the entire fractional
// component is always truncated.
assert_eq!(
    format!("{zdt:.0}"),
    "2024-06-15T07:00:00-04:00[US/Eastern]",
);
Source

impl Display for log::ParseLevelError

Source

impl Display for SetLoggerError

Source

impl Display for FromStrError

Source

impl Display for Mime

Source

impl Display for num_traits::ParseFloatError

Source

impl Display for Empty

Source

impl Display for ReadError

Source

impl Display for rand_core::error::Error

Source

impl Display for OsError

Source

impl Display for regex_automata::dfa::onepass::BuildError

Source

impl Display for regex_automata::error::Error

Source

impl Display for regex_automata::hybrid::error::BuildError

Source

impl Display for CacheError

Source

impl Display for regex_automata::meta::error::BuildError

Source

impl Display for regex_automata::nfa::thompson::error::BuildError

Source

impl Display for GroupInfoError

Source

impl Display for UnicodeWordBoundaryError

Source

impl Display for regex_automata::util::primitives::PatternIDError

Source

impl Display for SmallIndexError

Source

impl Display for regex_automata::util::primitives::StateIDError

Source

impl Display for regex_automata::util::search::MatchError

Source

impl Display for PatternSetInsertError

Source

impl Display for DeserializeError

Source

impl Display for SerializeError

Source

impl Display for regex_syntax::ast::Error

Source

impl Display for regex_syntax::ast::Error

Source

impl Display for regex_syntax::hir::Error

Source

impl Display for regex_syntax::hir::Error

Source

impl Display for regex_syntax::hir::Hir

Print a display representation of this Hir.

The result of this is a valid regular expression pattern string.

This implementation uses constant stack space and heap space proportional to the size of the Hir.

Source

impl Display for regex_syntax::hir::Hir

Print a display representation of this Hir.

The result of this is a valid regular expression pattern string.

This implementation uses constant stack space and heap space proportional to the size of the Hir.

Source

impl Display for regex_syntax::unicode::CaseFoldError

Source

impl Display for regex_syntax::unicode::CaseFoldError

Source

impl Display for regex_syntax::unicode::UnicodeWordError

Source

impl Display for regex_syntax::unicode::UnicodeWordError

Source

impl Display for regex::regex::bytes::Regex

Source

impl Display for CannotCloneRequestError

Source

impl Display for reqwest::error::Error

Source

impl Display for KeyRejected

Source

impl Display for Unspecified

Source

impl Display for Errno

Source

impl Display for rustls_native_certs::Error

Source

impl Display for rustls_pki_types::server_name::AddrParseError

Source

impl Display for InvalidDnsNameError

Source

impl Display for UnsupportedOperationError

Source

impl Display for OtherError

Source

impl Display for serde_json::error::Error

Source

impl Display for Number

Source

impl Display for PathPersistError

Source

impl Display for time::date::Date

Source

impl Display for Duration

The format returned by this implementation is not stable and must not be relied upon.

By default this produces an exact, full-precision printout of the duration. For a concise, rounded printout instead, you can use the .N format specifier:

let duration = Duration::new(123456, 789011223);
println!("{duration:.3}");

For the purposes of this implementation, a day is exactly 24 hours and a minute is exactly 60 seconds.

Source

impl Display for ComponentRange

Source

impl Display for ConversionRange

Source

impl Display for DifferentVariant

Source

impl Display for InvalidVariant

Source

impl Display for OffsetDateTime

Source

impl Display for PrimitiveDateTime

Source

impl Display for time::time::Time

Source

impl Display for UtcDateTime

Source

impl Display for UtcOffset

Source

impl Display for tokio_stream::stream_ext::timeout::Elapsed

Source

impl Display for LengthDelimitedCodecError

Source

impl Display for tokio::net::tcp::split_owned::ReuniteError

Source

impl Display for tokio::net::unix::split_owned::ReuniteError

Source

impl Display for TryCurrentError

Source

impl Display for JoinError

Source

impl Display for Id

Source

impl Display for AcquireError

Source

impl Display for tokio::sync::mutex::TryLockError

Source

impl Display for tokio::sync::watch::error::RecvError

Source

impl Display for tokio::time::error::Elapsed

Source

impl Display for tokio::time::error::Error

Source

impl Display for tower::timeout::error::Elapsed

Source

impl Display for None

Source

impl Display for InitError

Source

impl Display for SetGlobalDefaultError

Source

impl Display for Field

Source

impl Display for FieldSet

Source

impl Display for ValueSet<'_>

Source

impl Display for tracing_core::metadata::Level

Source

impl Display for tracing_core::metadata::LevelFilter

Source

impl Display for tracing_core::metadata::ParseLevelError

Source

impl Display for ParseLevelFilterError

Source

impl Display for tracing_subscriber::filter::directive::ParseError

Source

impl Display for Directive

Source

impl Display for BadName

Source

impl Display for EnvFilter

Source

impl Display for FromEnvError

Source

impl Display for Targets

Source

impl Display for tracing_subscriber::reload::Error

Source

impl Display for TryInitError

Source

impl Display for Url

Display the serialization of this URL.

Source

impl Display for Utf8CharsError

Source

impl Display for uuid::error::Error

Source

impl Display for Braced

Source

impl Display for Hyphenated

Source

impl Display for Simple

Source

impl Display for Urn

Source

impl Display for NonNilUuid

1.0.0 · Source

impl Display for batch_mode_3p::io::Error

Source

impl Display for batch_mode_3p::oneshot::error::RecvError

Source

impl Display for ApiError

Source

impl Display for batch_mode_3p::Regex

Source

impl Display for Uuid

1.26.0 · Source

impl Display for AccessError

Source

impl Display for dyn Expected + '_

Source

impl Display for dyn Value

Source

impl<'a> Display for Unexpected<'a>

1.60.0 · Source

impl<'a> Display for EscapeAscii<'a>

1.34.0 · Source

impl<'a> Display for core::str::iter::EscapeDebug<'a>

1.34.0 · Source

impl<'a> Display for core::str::iter::EscapeDefault<'a>

1.34.0 · Source

impl<'a> Display for core::str::iter::EscapeUnicode<'a>

Source

impl<'a> Display for ANSIGenericString<'a, str>

Source

impl<'a> Display for ANSIGenericStrings<'a, str>

Source

impl<'a> Display for mime::Name<'a>

Source

impl<'a> Display for PercentEncode<'a>

Source

impl<'a, 'e, E> Display for Base64Display<'a, 'e, E>
where E: Engine,

Source

impl<'a, I, B> Display for DelayedFormat<I>
where I: Iterator<Item = B> + Clone, B: Borrow<Item<'a>>,

Source

impl<'a, K, V> Display for std::collections::hash::map::OccupiedError<'a, K, V>
where K: Debug, V: Debug,

Source

impl<'a, K, V, A> Display for alloc::collections::btree::map::entry::OccupiedError<'a, K, V, A>
where K: Debug + Ord, V: Debug, A: Allocator + Clone,

Source

impl<'a, R, G, T> Display for MappedReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, G, T> Display for ReentrantMutexGuard<'a, R, G, T>
where R: RawMutex + 'a, G: GetThreadId + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::mutex::MappedMutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::mutex::MutexGuard<'a, R, T>
where R: RawMutex + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::MappedRwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::MappedRwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::RwLockReadGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for RwLockUpgradableReadGuard<'a, R, T>
where R: RawRwLockUpgrade + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, R, T> Display for lock_api::rwlock::RwLockWriteGuard<'a, R, T>
where R: RawRwLock + 'a, T: Display + 'a + ?Sized,

Source

impl<'a, T> Display for tokio::sync::mutex::MappedMutexGuard<'a, T>
where T: Display + ?Sized,

Source

impl<'a, T> Display for RwLockMappedWriteGuard<'a, T>
where T: Display + ?Sized,

Source

impl<'a, T> Display for batch_mode_3p::AsyncRwLockReadGuard<'a, T>
where T: Display + ?Sized,

Source

impl<'a, T> Display for batch_mode_3p::AsyncRwLockWriteGuard<'a, T>
where T: Display + ?Sized,

Source

impl<'a, TLeft, TRight> Display for Comparison<'a, TLeft, TRight>
where TLeft: Debug + ?Sized, TRight: Debug + ?Sized,

Source

impl<'a, TLeft, TRight> Display for StrComparison<'a, TLeft, TRight>
where TLeft: AsRef<str> + ?Sized, TRight: AsRef<str> + ?Sized,

Source

impl<'d> Display for TimeZoneName<'d>

Source

impl<'f> Display for jiff::fmt::strtime::Display<'f>

Source

impl<'i, R> Display for Pair<'i, R>
where R: RuleType,

Source

impl<'i, R> Display for Pairs<'i, R>
where R: RuleType,

Source

impl<'n> Display for Pieces<'n>

Source

impl<'n, 'e> Display for App<'n, 'e>

Source

impl<A, S, V> Display for ConvertError<A, S, V>
where A: Display, S: Display, V: Display,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

1.0.0 · Source

impl<B> Display for Cow<'_, B>
where B: Display + ToOwned + ?Sized, <B as ToOwned>::Owned: Display,

Source

impl<E> Display for backoff::error::Error<E>
where E: Display,

Source

impl<E> Display for EventStreamError<E>
where E: Display,

Source

impl<E> Display for Err<E>
where E: Debug,

Source

impl<E> Display for Report<E>
where E: Error,

Source

impl<E> Display for FormattedFields<E>
where E: ?Sized,

Source

impl<F> Display for FromFn<F>
where F: Fn(&mut Formatter<'_>) -> Result<(), Error>,

Source

impl<F> Display for PersistError<F>

Source

impl<I> Display for nom::error::Error<I>
where I: Display,

The Display implementation allows the std::error::Error implementation

Source

impl<I> Display for VerboseError<I>
where I: Display,

Source

impl<O> Display for F32<O>
where O: ByteOrder,

Source

impl<O> Display for F64<O>
where O: ByteOrder,

Source

impl<O> Display for I16<O>
where O: ByteOrder,

Source

impl<O> Display for I32<O>
where O: ByteOrder,

Source

impl<O> Display for I64<O>
where O: ByteOrder,

Source

impl<O> Display for I128<O>
where O: ByteOrder,

Source

impl<O> Display for Isize<O>
where O: ByteOrder,

Source

impl<O> Display for U16<O>
where O: ByteOrder,

Source

impl<O> Display for U32<O>
where O: ByteOrder,

Source

impl<O> Display for U64<O>
where O: ByteOrder,

Source

impl<O> Display for U128<O>
where O: ByteOrder,

Source

impl<O> Display for Usize<O>
where O: ByteOrder,

1.33.0 · Source

impl<Ptr> Display for Pin<Ptr>
where Ptr: Display,

Source

impl<R> Display for ErrorVariant<R>
where R: RuleType,

Source

impl<R> Display for pest::error::Error<R>
where R: RuleType,

Source

impl<S> Display for Host<S>
where S: AsRef<str>,

Source

impl<S> Display for Built<'_, RiAbsoluteStr<S>>
where S: Spec,

Source

impl<S> Display for Built<'_, RiStr<S>>
where S: Spec,

Source

impl<S> Display for Built<'_, RiReferenceStr<S>>
where S: Spec,

Source

impl<S> Display for Built<'_, RiRelativeStr<S>>
where S: Spec,

Source

impl<S> Display for MappedToUri<'_, RiAbsoluteStr<S>>
where S: Spec,

Source

impl<S> Display for MappedToUri<'_, RiFragmentStr<S>>
where S: Spec,

Source

impl<S> Display for MappedToUri<'_, RiStr<S>>
where S: Spec,

Source

impl<S> Display for MappedToUri<'_, RiQueryStr<S>>
where S: Spec,

Source

impl<S> Display for MappedToUri<'_, RiReferenceStr<S>>
where S: Spec,

Source

impl<S> Display for MappedToUri<'_, RiRelativeStr<S>>
where S: Spec,

Source

impl<S> Display for PasswordMasked<'_, RiAbsoluteStr<S>>
where S: Spec,

Source

impl<S> Display for PasswordMasked<'_, RiStr<S>>
where S: Spec,

Source

impl<S> Display for PasswordMasked<'_, RiReferenceStr<S>>
where S: Spec,

Source

impl<S> Display for PasswordMasked<'_, RiRelativeStr<S>>
where S: Spec,

Source

impl<S> Display for Normalized<'_, RiAbsoluteStr<S>>
where S: Spec,

Source

impl<S> Display for Normalized<'_, RiStr<S>>
where S: Spec,

Source

impl<S> Display for RiAbsoluteStr<S>
where S: Spec,

Source

impl<S> Display for RiAbsoluteString<S>
where S: Spec,

Source

impl<S> Display for RiFragmentStr<S>
where S: Spec,

Source

impl<S> Display for RiFragmentString<S>
where S: Spec,

Source

impl<S> Display for RiStr<S>
where S: Spec,

Source

impl<S> Display for RiString<S>
where S: Spec,

Source

impl<S> Display for RiQueryStr<S>
where S: Spec,

Source

impl<S> Display for RiQueryString<S>
where S: Spec,

Source

impl<S> Display for RiReferenceStr<S>
where S: Spec,

Source

impl<S> Display for RiReferenceString<S>
where S: Spec,

Source

impl<S> Display for RiRelativeStr<S>
where S: Spec,

Source

impl<S> Display for RiRelativeString<S>
where S: Spec,

Source

impl<S> Display for Ascii<S>
where S: Display,

Source

impl<S> Display for UniCase<S>
where S: Display,

Source

impl<S, C> Display for Expanded<'_, S, C>
where S: Spec, C: Context,

Source

impl<S, D> Display for PasswordReplaced<'_, RiAbsoluteStr<S>, D>
where S: Spec, D: Display,

Source

impl<S, D> Display for PasswordReplaced<'_, RiStr<S>, D>
where S: Spec, D: Display,

Source

impl<S, D> Display for PasswordReplaced<'_, RiReferenceStr<S>, D>
where S: Spec, D: Display,

Source

impl<S, D> Display for PasswordReplaced<'_, RiRelativeStr<S>, D>
where S: Spec, D: Display,

Source

impl<Src, Dst> Display for AlignmentError<Src, Dst>
where Src: Deref, Dst: KnownLayout + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<Src, Dst> Display for SizeError<Src, Dst>
where Src: Deref, Dst: KnownLayout + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<Src, Dst> Display for ValidityError<Src, Dst>
where Src: Deref, Dst: KnownLayout + TryFromBytes + ?Sized,

Produces a human-readable error message.

The message differs between debug and release builds. When debug_assertions are enabled, this message is verbose and includes potentially sensitive information.

Source

impl<T> Display for batch_mode_3p::TrySendError<T>

Source

impl<T> Display for std::sync::mpmc::error::SendTimeoutError<T>

1.0.0 · Source

impl<T> Display for std::sync::mpsc::TrySendError<T>

1.0.0 · Source

impl<T> Display for std::sync::poison::TryLockError<T>

Source

impl<T> Display for crossbeam_channel::err::SendTimeoutError<T>

Source

impl<T> Display for crossbeam_channel::err::TrySendError<T>

Source

impl<T> Display for SetError<T>

Source

impl<T> Display for batch_mode_3p::mpsc::error::SendTimeoutError<T>

1.0.0 · Source

impl<T> Display for &T
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for &mut T
where T: Display + ?Sized,

Source

impl<T> Display for ThinBox<T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for core::cell::Ref<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for RefMut<'_, T>
where T: Display + ?Sized,

1.28.0 · Source

impl<T> Display for NonZero<T>

1.74.0 · Source

impl<T> Display for Saturating<T>
where T: Display,

1.10.0 · Source

impl<T> Display for Wrapping<T>
where T: Display,

1.0.0 · Source

impl<T> Display for std::sync::mpsc::SendError<T>

Source

impl<T> Display for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::mutex::MappedMutexGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockReadGuard<'_, T>
where T: Display + ?Sized,

1.20.0 · Source

impl<T> Display for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>
where T: Display + ?Sized,

1.0.0 · Source

impl<T> Display for PoisonError<T>

Source

impl<T> Display for ReentrantLockGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for crossbeam_channel::err::SendError<T>

Source

impl<T> Display for CachePadded<T>
where T: Display,

Source

impl<T> Display for ShardedLockReadGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for ShardedLockWriteGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for futures_channel::mpsc::TrySendError<T>

Source

impl<T> Display for futures_util::io::split::ReuniteError<T>

Source

impl<T> Display for Port<T>

Source

impl<T> Display for iri_string::template::error::CreationError<T>

Source

impl<T> Display for iri_string::types::generic::error::CreationError<T>

Source

impl<T> Display for PollSendError<T>

Source

impl<T> Display for tokio::sync::broadcast::error::SendError<T>

Source

impl<T> Display for tokio::sync::mutex::MutexGuard<'_, T>
where T: Display + ?Sized,

Source

impl<T> Display for OwnedMutexGuard<T>
where T: Display + ?Sized,

Source

impl<T> Display for OwnedRwLockWriteGuard<T>
where T: Display + ?Sized,

Source

impl<T> Display for tokio::sync::watch::error::SendError<T>

Source

impl<T> Display for DisplayValue<T>
where T: Display,

Source

impl<T> Display for LossyWrap<T>
where T: TryWriteable,

Source

impl<T> Display for WithPart<T>
where T: Writeable + ?Sized,

Source

impl<T> Display for TryWriteableInfallibleAsWriteable<T>
where T: TryWriteable<Error = Infallible>,

Source

impl<T> Display for Painted<T>
where T: Display,

Source

impl<T> Display for Unalign<T>
where T: Unaligned + Display,

Source

impl<T> Display for AsyncFdTryNewError<T>

Source

impl<T> Display for batch_mode_3p::mpsc::error::SendError<T>

1.0.0 · Source

impl<T, A> Display for Box<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueRc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, A> Display for UniqueArc<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Arc<T, A>
where T: Display + ?Sized, A: Allocator,

1.0.0 · Source

impl<T, A> Display for Rc<T, A>
where T: Display + ?Sized, A: Allocator,

Source

impl<T, B> Display for zerocopy::ref::def::Ref<B, T>

Source

impl<T, E> Display for TryChunksError<T, E>
where E: Display,

Source

impl<T, E> Display for TryReadyChunksError<T, E>
where E: Display,

Source

impl<T, Item> Display for futures_util::stream::stream::split::ReuniteError<T, Item>

Source

impl<T, S> Display for PercentEncoded<T, S>
where T: Display, S: Spec,

Source

impl<T, U> Display for OwnedMappedMutexGuard<T, U>
where U: Display + ?Sized, T: ?Sized,

Source

impl<T, U> Display for OwnedRwLockReadGuard<T, U>
where U: Display + ?Sized, T: ?Sized,

Source

impl<T, U> Display for OwnedRwLockMappedWriteGuard<T, U>
where U: Display + ?Sized, T: ?Sized,

Source

impl<Tz> Display for chrono::date::Date<Tz>
where Tz: TimeZone, <Tz as TimeZone>::Offset: Display,

Source

impl<Tz> Display for chrono::datetime::DateTime<Tz>
where Tz: TimeZone, <Tz as TimeZone>::Offset: Display,

1.0.0 · Source

impl<W> Display for IntoInnerError<W>

Source

impl<const MIN: i8, const MAX: i8> Display for RangedI8<MIN, MAX>

Source

impl<const MIN: i16, const MAX: i16> Display for RangedI16<MIN, MAX>

Source

impl<const MIN: i32, const MAX: i32> Display for RangedI32<MIN, MAX>

Source

impl<const MIN: i64, const MAX: i64> Display for RangedI64<MIN, MAX>

Source

impl<const MIN: i128, const MAX: i128> Display for RangedI128<MIN, MAX>

Source

impl<const MIN: isize, const MAX: isize> Display for RangedIsize<MIN, MAX>

Source

impl<const MIN: u8, const MAX: u8> Display for RangedU8<MIN, MAX>

Source

impl<const MIN: u16, const MAX: u16> Display for RangedU16<MIN, MAX>

Source

impl<const MIN: u32, const MAX: u32> Display for RangedU32<MIN, MAX>

Source

impl<const MIN: u64, const MAX: u64> Display for RangedU64<MIN, MAX>

Source

impl<const MIN: u128, const MAX: u128> Display for RangedU128<MIN, MAX>

Source

impl<const MIN: usize, const MAX: usize> Display for RangedUsize<MIN, MAX>

Source

impl<const N: usize> Display for TinyAsciiStr<N>

Source

impl<const SIZE: usize> Display for WriteBuffer<SIZE>