pub trait __Deref {
type Target: ?Sized;
// Required method
fn deref(&self) -> &Self::Target;
}Expand description
Used for immutable dereferencing operations, like *v.
In addition to being used for explicit dereferencing operations with the
(unary) * operator in immutable contexts, Deref is also used implicitly
by the compiler in many circumstances. This mechanism is called
“Deref coercion”. In mutable contexts, DerefMut is used and
mutable deref coercion similarly occurs.
Warning: Deref coercion is a powerful language feature which has
far-reaching implications for every type that implements Deref. The
compiler will silently insert calls to Deref::deref. For this reason, one
should be careful about implementing Deref and only do so when deref
coercion is desirable. See below for advice on when this is
typically desirable or undesirable.
Types that implement Deref or DerefMut are often called “smart
pointers” and the mechanism of deref coercion has been specifically designed
to facilitate the pointer-like behavior that name suggests. Often, the
purpose of a “smart pointer” type is to change the ownership semantics
of a contained value (for example, Rc or Cow) or the
storage semantics of a contained value (for example, Box).
Deref coercion
If T implements Deref<Target = U>, and v is a value of type T, then:
- In immutable contexts,
*v(whereTis neither a reference nor a raw pointer) is equivalent to*Deref::deref(&v). - Values of type
&Tare coerced to values of type&U Timplicitly implements all the methods of the typeUwhich take the&selfreceiver.
For more details, visit the chapter in The Rust Programming Language as well as the reference sections on the dereference operator, method resolution, and type coercions.
When to implement Deref or DerefMut
The same advice applies to both deref traits. In general, deref traits should be implemented if:
- a value of the type transparently behaves like a value of the target type;
- the implementation of the deref function is cheap; and
- users of the type will not be surprised by any deref coercion behavior.
In general, deref traits should not be implemented if:
- the deref implementations could fail unexpectedly; or
- the type has methods that are likely to collide with methods on the target type; or
- committing to deref coercion as part of the public API is not desirable.
Note that there’s a large difference between implementing deref traits generically over many target types, and doing so only for specific target types.
Generic implementations, such as for Box<T> (which is generic over
every type and dereferences to T) should be careful to provide few or no
methods, since the target type is unknown and therefore every method could
collide with one on the target type, causing confusion for users.
impl<T> Box<T> has no methods (though several associated functions),
partly for this reason.
Specific implementations, such as for String (whose Deref
implementation has Target = str) can have many methods, since avoiding
collision is much easier. String and str both have many methods, and
String additionally behaves as if it has every method of str because of
deref coercion. The implementing type may also be generic while the
implementation is still specific in this sense; for example, Vec<T>
dereferences to [T], so methods of T are not applicable.
Consider also that deref coercion means that deref traits are a much larger part of a type’s public API than any other trait as it is implicitly called by the compiler. Therefore, it is advisable to consider whether this is something you are comfortable supporting as a public API.
The AsRef and Borrow traits have very similar
signatures to Deref. It may be desirable to implement either or both of
these, whether in addition to or rather than deref traits. See their
documentation for details.
Fallibility
This trait’s method should never unexpectedly fail. Deref coercion means
the compiler will often insert calls to Deref::deref implicitly. Failure
during dereferencing can be extremely confusing when Deref is invoked
implicitly. In the majority of uses it should be infallible, though it may
be acceptable to panic if the type is misused through programmer error, for
example.
However, infallibility is not enforced and therefore not guaranteed.
As such, unsafe code should not rely on infallibility in general for
soundness.
Examples
A struct with a single field which is accessible by dereferencing the struct.
use std::ops::Deref;
struct DerefExample<T> {
value: T
}
impl<T> Deref for DerefExample<T> {
type Target = T;
fn deref(&self) -> &Self::Target {
&self.value
}
}
let x = DerefExample { value: 'a' };
assert_eq!('a', *x);Required Associated Types
Required Methods
Implementors
Sourceimpl Deref for rustls::conn::connection::Connection
impl Deref for rustls::conn::connection::Connection
type Target = CommonState
Sourceimpl Deref for rustls::quic::connection::Connection
impl Deref for rustls::quic::connection::Connection
type Target = CommonState
Sourceimpl Deref for SHOULD_COLORIZE
impl Deref for SHOULD_COLORIZE
type Target = ShouldColorize
Sourceimpl Deref for CurrencyType
impl Deref for CurrencyType
type Target = TinyAsciiStr<3>
Sourceimpl Deref for RegionOverride
impl Deref for RegionOverride
type Target = SubdivisionId
Sourceimpl Deref for RegionalSubdivision
impl Deref for RegionalSubdivision
type Target = SubdivisionId
Sourceimpl Deref for UriTemplateString
impl Deref for UriTemplateString
type Target = UriTemplateStr
Sourceimpl Deref for rustls::client::client_conn::connection::ClientConnection
impl Deref for rustls::client::client_conn::connection::ClientConnection
Sourceimpl Deref for UnbufferedClientConnection
impl Deref for UnbufferedClientConnection
Sourceimpl Deref for rustls::quic::connection::ClientConnection
impl Deref for rustls::quic::connection::ClientConnection
Sourceimpl Deref for rustls::quic::connection::ServerConnection
impl Deref for rustls::quic::connection::ServerConnection
Sourceimpl Deref for rustls::server::server_conn::connection::ServerConnection
impl Deref for rustls::server::server_conn::connection::ServerConnection
Sourceimpl Deref for UnbufferedServerConnection
impl Deref for UnbufferedServerConnection
Sourceimpl<'a> Deref for MaybeUninitSlice<'a>
impl<'a> Deref for MaybeUninitSlice<'a>
type Target = [MaybeUninit<u8>]
Sourceimpl<'a, R, G, T> Deref for MappedReentrantMutexGuard<'a, R, G, T>
impl<'a, R, G, T> Deref for MappedReentrantMutexGuard<'a, R, G, T>
Sourceimpl<'a, R, G, T> Deref for ReentrantMutexGuard<'a, R, G, T>
impl<'a, R, G, T> Deref for ReentrantMutexGuard<'a, R, G, T>
Sourceimpl<'a, R, T> Deref for lock_api::mutex::MappedMutexGuard<'a, R, T>
impl<'a, R, T> Deref for lock_api::mutex::MappedMutexGuard<'a, R, T>
Sourceimpl<'a, R, T> Deref for lock_api::mutex::MutexGuard<'a, R, T>
impl<'a, R, T> Deref for lock_api::mutex::MutexGuard<'a, R, T>
Sourceimpl<'a, R, T> Deref for lock_api::rwlock::MappedRwLockReadGuard<'a, R, T>
impl<'a, R, T> Deref for lock_api::rwlock::MappedRwLockReadGuard<'a, R, T>
Sourceimpl<'a, R, T> Deref for lock_api::rwlock::MappedRwLockWriteGuard<'a, R, T>
impl<'a, R, T> Deref for lock_api::rwlock::MappedRwLockWriteGuard<'a, R, T>
Sourceimpl<'a, R, T> Deref for lock_api::rwlock::RwLockReadGuard<'a, R, T>
impl<'a, R, T> Deref for lock_api::rwlock::RwLockReadGuard<'a, R, T>
Sourceimpl<'a, R, T> Deref for RwLockUpgradableReadGuard<'a, R, T>where
R: RawRwLockUpgrade + 'a,
T: 'a + ?Sized,
impl<'a, R, T> Deref for RwLockUpgradableReadGuard<'a, R, T>where
R: RawRwLockUpgrade + 'a,
T: 'a + ?Sized,
Sourceimpl<'a, R, T> Deref for lock_api::rwlock::RwLockWriteGuard<'a, R, T>
impl<'a, R, T> Deref for lock_api::rwlock::RwLockWriteGuard<'a, R, T>
Sourceimpl<'a, S> Deref for ANSIGenericString<'a, S>
impl<'a, S> Deref for ANSIGenericString<'a, S>
Sourceimpl<'a, T> Deref for tokio::sync::mutex::MappedMutexGuard<'a, T>where
T: ?Sized,
impl<'a, T> Deref for tokio::sync::mutex::MappedMutexGuard<'a, T>where
T: ?Sized,
Sourceimpl<C0, C1, T> Deref for EitherCart<C0, C1>
impl<C0, C1, T> Deref for EitherCart<C0, C1>
Sourceimpl<Data> Deref for rustls::quic::connection::ConnectionCommon<Data>
impl<Data> Deref for rustls::quic::connection::ConnectionCommon<Data>
type Target = CommonState
Sourceimpl<S> Deref for RiAbsoluteString<S>where
S: Spec,
impl<S> Deref for RiAbsoluteString<S>where
S: Spec,
type Target = RiAbsoluteStr<S>
Sourceimpl<S> Deref for RiFragmentString<S>where
S: Spec,
impl<S> Deref for RiFragmentString<S>where
S: Spec,
type Target = RiFragmentStr<S>
Sourceimpl<S> Deref for RiQueryString<S>where
S: Spec,
impl<S> Deref for RiQueryString<S>where
S: Spec,
type Target = RiQueryStr<S>
Sourceimpl<S> Deref for RiReferenceString<S>where
S: Spec,
impl<S> Deref for RiReferenceString<S>where
S: Spec,
type Target = RiReferenceStr<S>
Sourceimpl<S> Deref for RiRelativeString<S>where
S: Spec,
impl<S> Deref for RiRelativeString<S>where
S: Spec,
type Target = RiRelativeStr<S>
Sourceimpl<T> Deref for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>where
T: ?Sized,
impl<T> Deref for std::sync::nonpoison::mutex::MappedMutexGuard<'_, T>where
T: ?Sized,
Sourceimpl<T> Deref for std::sync::nonpoison::mutex::MutexGuard<'_, T>where
T: ?Sized,
impl<T> Deref for std::sync::nonpoison::mutex::MutexGuard<'_, T>where
T: ?Sized,
Sourceimpl<T> Deref for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>where
T: ?Sized,
impl<T> Deref for std::sync::nonpoison::rwlock::MappedRwLockReadGuard<'_, T>where
T: ?Sized,
Sourceimpl<T> Deref for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>where
T: ?Sized,
impl<T> Deref for std::sync::nonpoison::rwlock::MappedRwLockWriteGuard<'_, T>where
T: ?Sized,
Sourceimpl<T> Deref for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>where
T: ?Sized,
impl<T> Deref for std::sync::nonpoison::rwlock::RwLockReadGuard<'_, T>where
T: ?Sized,
Sourceimpl<T> Deref for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>where
T: ?Sized,
impl<T> Deref for std::sync::nonpoison::rwlock::RwLockWriteGuard<'_, T>where
T: ?Sized,
Sourceimpl<T> Deref for std::sync::poison::mutex::MappedMutexGuard<'_, T>where
T: ?Sized,
impl<T> Deref for std::sync::poison::mutex::MappedMutexGuard<'_, T>where
T: ?Sized,
1.0.0 · Sourceimpl<T> Deref for std::sync::poison::mutex::MutexGuard<'_, T>where
T: ?Sized,
impl<T> Deref for std::sync::poison::mutex::MutexGuard<'_, T>where
T: ?Sized,
Sourceimpl<T> Deref for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>where
T: ?Sized,
impl<T> Deref for std::sync::poison::rwlock::MappedRwLockReadGuard<'_, T>where
T: ?Sized,
Sourceimpl<T> Deref for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>where
T: ?Sized,
impl<T> Deref for std::sync::poison::rwlock::MappedRwLockWriteGuard<'_, T>where
T: ?Sized,
1.0.0 · Sourceimpl<T> Deref for std::sync::poison::rwlock::RwLockReadGuard<'_, T>where
T: ?Sized,
impl<T> Deref for std::sync::poison::rwlock::RwLockReadGuard<'_, T>where
T: ?Sized,
1.0.0 · Sourceimpl<T> Deref for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>where
T: ?Sized,
impl<T> Deref for std::sync::poison::rwlock::RwLockWriteGuard<'_, T>where
T: ?Sized,
Sourceimpl<T> Deref for futures_util::lock::mutex::MutexGuard<'_, T>where
T: ?Sized,
impl<T> Deref for futures_util::lock::mutex::MutexGuard<'_, T>where
T: ?Sized,
Sourceimpl<T> Deref for futures_util::lock::mutex::OwnedMutexGuard<T>where
T: ?Sized,
impl<T> Deref for futures_util::lock::mutex::OwnedMutexGuard<T>where
T: ?Sized,
Sourceimpl<T> Deref for Metadata<'_, T>where
T: SmartDisplay + ?Sized,
Permit using Metadata as a smart pointer to the user-provided metadata.
impl<T> Deref for Metadata<'_, T>where
T: SmartDisplay + ?Sized,
Permit using Metadata as a smart pointer to the user-provided metadata.